@@ -608,6 +608,11 @@ class BaseVariable(BaseObject):
 class Variable(BaseVariable):
     @property
     def chunks(self):
+        if self.shape == ():
+            # In HSDS, the layout can be chunked even for scalar datasets, but with only a single chunk.
+            # Return None for scalar datasets since they shall be handled as non-chunked.
+            assert self._h5ds.chunks in (None, (), (1,))
+            return None
         return self._h5ds.chunks
 
     @property
@@ -1505,7 +1510,7 @@ class File(Group):
         self._close_h5file = True
         try:
             if isinstance(path, str):
-                if (
+                if kwargs.get("driver") == "h5pyd" or (
                     path.startswith(("http://", "https://", "hdf5://"))
                     and "driver" not in kwargs
                 ):
