@@ -2,9 +2,7 @@ import weakref
 from collections import OrderedDict
 from collections.abc import MutableMapping
 
-import h5py
 import numpy as np
-from packaging.version import Version
 
 
 class Dimensions(MutableMapping):
@@ -24,7 +22,7 @@ class Dimensions(MutableMapping):
         if not self._group._root._writable:
             raise RuntimeError("H5NetCDF: Write to read only")
         if name in self._objects:
-            raise ValueError("dimension %r already exists" % name)
+            raise ValueError(f"dimension {name:!r} already exists")
 
         self._objects[name] = Dimension(self._group, name, size, create_h5ds=True)
 
@@ -41,8 +39,7 @@ class Dimensions(MutableMapping):
         raise NotImplementedError("cannot yet delete dimensions")
 
     def __iter__(self):
-        for key in self._objects:
-            yield key
+        yield from self._objects
 
     def __len__(self):
         return len(self._objects)
@@ -50,16 +47,15 @@ class Dimensions(MutableMapping):
     def __repr__(self):
         if self._group._root._closed:
             return "<Closed h5netcdf.Dimensions>"
-        return "<h5netcdf.Dimensions: %s>" % ", ".join(
-            "%s=%r" % (k, v) for k, v in self._objects.items()
-        )
+        dims = ", ".join(f"{k}={v!r}" for k, v in self._objects.items())
+        return f"<h5netcdf.Dimensions: {dims}>"
 
 
 def _join_h5paths(parent_path, child_path):
     return "/".join([parent_path.rstrip("/"), child_path.lstrip("/")])
 
 
-class Dimension(object):
+class Dimension:
     def __init__(self, parent, name, size=None, create_h5ds=False, phony=False):
         """NetCDF4 Dimension constructor.
 
@@ -140,7 +136,7 @@ class Dimension(object):
 
     @property
     def _isscale(self):
-        return h5py.h5ds.is_scale(self._h5ds.id)
+        return self._root._h5py.h5ds.is_scale(self._h5ds.id)
 
     @property
     def _dimid(self):
@@ -153,8 +149,7 @@ class Dimension(object):
 
         if not self.isunlimited():
             raise ValueError(
-                "Dimension '%s' is not unlimited and thus cannot be resized."
-                % self.name
+                f"Dimension '{self.name}' is not unlimited and thus cannot be resized."
             )
         self._h5ds.resize((size,))
 
@@ -209,10 +204,7 @@ class Dimension(object):
         )
         # don't re-create scales if they already exist.
         if not self._root._h5py.h5ds.is_scale(self._h5ds.id):
-            if Version(h5py.__version__) < Version("2.10.0"):
-                self._h5ds.dims.create_scale(self._h5ds, scale_name)
-            else:
-                self._h5ds.make_scale(scale_name)
+            self._h5ds.make_scale(scale_name)
 
     def _attach_scale(self, refs):
         """Attach dimension scale to references"""
@@ -239,11 +231,11 @@ class Dimension(object):
 
     def __repr__(self):
         if not self._phony and self._parent._root._closed:
-            return "<Closed %s>" % self._cls_name
+            return f"<Closed {self._cls_name}>"
         special = ""
         if self._phony:
             special += " (phony_dim)"
         if self.isunlimited():
             special += " (unlimited)"
-        header = "<%s %r: size %s%s>" % (self._cls_name, self.name, self.size, special)
+        header = f"<{self._cls_name} {self.name!r}: size {self.size}{special}>"
         return "\n".join([header])
